Signer

Struct Signer 

pub struct Signer<'a> { /* private fields */ }
Signer struct containing a signature scheme and a signing key.

Example

use oqs;
use signature::{Signer,Verifier};
oqs::init();
let scheme = oqs::sig::Sig::new(oqs::sig::Algorithm::MlDsa44).unwrap();
let message = [0u8; 100];
let (pk, sk) = scheme.keypair().unwrap();
let signer = oqs::sig::Signer::new(&scheme,sk);
let verifier = oqs::sig::Verifier::new(&scheme,pk);
let signature = signer.try_sign(&message).unwrap();
assert!(verifier.verify(&message, &signature).is_ok());

Implementations

Source

impl<'a> Signer<'a>

pub fn new(scheme: &'a Sig, sk: SecretKey) -> Self

Creates a new Signer with the given signature scheme and secret key.