Verifier

Struct Verifier 

pub struct Verifier<'a> { /* private fields */ }
Verifier struct containing a signature scheme and a public verification key.

Example

use oqs;
use signature::{Signer,Verifier};
oqs::init();
let scheme = oqs::sig::Sig::new(oqs::sig::Algorithm::MlDsa44).unwrap();
let message = [0u8; 100];
let (pk, sk) = scheme.keypair().unwrap();
let signer = oqs::sig::Signer::new(&scheme,sk);
let verifier = oqs::sig::Verifier::new(&scheme,pk);
let signature = signer.try_sign(&message).unwrap();
assert!(verifier.verify(&message, &signature).is_ok());

Used to verify signatures for a given message.

Implementations

Source

impl<'a> Verifier<'a>

pub fn new(scheme: &'a Sig, pk: PublicKey) -> Self

Creates a new Verifier with the given signature scheme and public key.